@@ -8,13 +8,12 @@ import textwrap
 
 from .constants import LIST_EMAIL_DOMAINS, LOREM_TEXT
 
+
 class DataCreator:
     @staticmethod
     def create_random_string(
-        max_value: int = 800,
-        use_punctuation: bool = False,
-        use_digits: bool = True
-    ):
+        max_value: int = 800, use_punctuation: bool = False, use_digits: bool = True
+    ) -> str:
         min_value = 10
         characters = string.ascii_letters
         if use_digits:
@@ -27,7 +26,7 @@ class DataCreator:
         return "".join(random.choice(characters) for _ in range(number))
 
     @staticmethod
-    def create_random_text(max_value: int = 1000):
+    def create_random_text(max_value: int = 1000) -> str:
         return textwrap.wrap(LOREM_TEXT, max_value)[0]
 
     @staticmethod
@@ -52,39 +51,38 @@ class DataCreator:
         return random_dict
 
     @staticmethod
-    def create_random_slug(max_value: int = 800, use_digits: bool = True):
+    def create_random_slug(max_value: int = 800, use_digits: bool = True) -> str:
         return "-".join(
             [
-                DataCreator.create_random_string(3, 10, False, use_digits) for _ in range(4)
+                DataCreator.create_random_string(
+                    max_value=max_value, use_punctuation=False, use_digits=use_digits
+                )
+                for _ in range(4)
             ]
         )[:max_value]
 
-
     @staticmethod
-    def create_random_email(max_value: int = 25):
+    def create_random_email(max_value: int = 25) -> str:
         email_name = DataCreator.create_random_string(max_value)
         email_domain = random.choice(LIST_EMAIL_DOMAINS)
         return f"{email_name}@{email_domain}"
 
     @staticmethod
-    def create_random_url(max_value: int = 100, secure=True):
+    def create_random_url(max_value: int = 100, secure=True) -> str:
         domain = DataCreator.create_random_string(max_value)
         top_level_domain = random.choice(LIST_EMAIL_DOMAINS).split(".")[-1]
         protocol = "https" if secure else "http"
         return f"{protocol}://{domain}.{top_level_domain}"
 
     @staticmethod
-    def create_random_uuid(kind: int = 4, **kwargs):
-        uuids = {
-            1: uuid.uuid1,
-            3: uuid.uuid3,
-            4: uuid.uuid4,
-            5: uuid.uuid5
-        }
+    def create_random_uuid(kind: int = 4, **kwargs) -> uuid.UUID:
+        uuids = {1: uuid.uuid1, 3: uuid.uuid3, 4: uuid.uuid4, 5: uuid.uuid5}
         return uuids[kind](**kwargs)
 
     @staticmethod
-    def create_random_date(day: int = None, month: int = None, year: int = None):
+    def create_random_date(
+        day: int = None, month: int = None, year: int = None
+    ) -> datetime.date:
         month = month if month else random.randint(1, 12)
         if month == 2:
             max_day = 28
@@ -97,7 +95,9 @@ class DataCreator:
         return datetime.date(year=year, month=month, day=day)
 
     @staticmethod
-    def create_random_hour(hour: int = None, minute: int = None, second: int = None):
+    def create_random_hour(
+        hour: int = None, minute: int = None, second: int = None
+    ) -> datetime.time:
         hour = hour if hour else random.randint(0, 23)
         minute = minute if minute else random.randint(0, 59)
         second = second if second else random.randint(0, 59)
@@ -111,41 +111,57 @@ class DataCreator:
         hour: int = None,
         minute: int = None,
         second: int = None,
-    ):
+    ) -> datetime.datetime:
         date = DataCreator.create_random_date(day, month, year)
         time = DataCreator.create_random_hour(hour, minute, second)
         return datetime.datetime.combine(date, time)
 
     @staticmethod
-    def create_random_integer(min_value: int = 0, max_value: int = 10000000):
+    def create_random_integer(min_value: int = 0, max_value: int = 10000000) -> int:
         if max_value < min_value:
             min_value += max_value - min_value
         fnct = random.choice(
-            [DataCreator.create_random_negative_integer, DataCreator.create_random_positive_integer]
+            [
+                DataCreator.create_random_negative_integer,
+                DataCreator.create_random_positive_integer,
+            ]
         )
         return fnct(min_value, max_value)
 
     @staticmethod
-    def create_random_negative_integer(min_value: int = 0, max_value: int = 10000000):
-        return (random.randint(min_value, max_value) * -1)
+    def create_random_negative_integer(
+        min_value: int = 0, max_value: int = 10000000
+    ) -> int:
+        return random.randint(min_value, max_value) * -1
 
     @staticmethod
-    def create_random_positive_integer(min_value: int = 0, max_value: int = 10000000):
+    def create_random_positive_integer(
+        min_value: int = 0, max_value: int = 10000000
+    ) -> int:
         return random.randint(min_value, max_value)
 
     @staticmethod
-    def create_random_float(min_value: float = 0, max_value: float = 10000000, after_coma: int = 2):
+    def create_random_float(
+        min_value: float = 0, max_value: float = 10000000, after_coma: int = 2
+    ) -> float:
         if max_value < min_value:
             min_value += max_value - min_value
         fnct = random.choice(
-            [DataCreator.create_random_negative_float, DataCreator.create_random_positive_float]
+            [
+                DataCreator.create_random_negative_float,
+                DataCreator.create_random_positive_float,
+            ]
         )
         return fnct(min_value, max_value, after_coma)
 
     @staticmethod
-    def create_random_positive_float(min_value: float = 0, max_value: float = 10000000, after_coma: int = 2):
+    def create_random_positive_float(
+        min_value: float = 0, max_value: float = 10000000, after_coma: int = 2
+    ) -> float:
         return round(random.uniform(min_value, max_value), after_coma)
 
     @staticmethod
-    def create_random_negative_float(min_value: float = 0, max_value: float = 10000000, after_coma: int = 2):
-        return (round(random.uniform(min_value, max_value), after_coma) * -1)
+    def create_random_negative_float(
+        min_value: float = 0, max_value: float = 10000000, after_coma: int = 2
+    ) -> float:
+        return round(random.uniform(min_value, max_value), after_coma) * -1
